----------------------------------------------------
-- Thermal Capacitor Equivelant
-- 
-- Author: Allan Ecker
-- Created: August 8, 2003
--
-------------------------------------------------------------------------------
-- Description:
-- Model the relation between heat flow, temperature and thermal 
-- properties of a material as a capacitive element
-------------------------------------------------------------------------------

package thermal_system is
        nature thermal is real across real through;
        terminal thermal_ground : thermal;
end thermal_system;
        
use thermal_system.all;

entity thC is
	generic ( 
                C : real := 1.0e1 -- Watts per kelvin per second
	);
	port ( 
		terminal t1, t2 : thermal
	);
end thC;


architecture arch1 of thC is
	quantity temperature across HeatProduced through t1 to t2;
begin
  Thermal_equations: procedural is
  begin -- procedural statements                              
        HeatProduced := C*temperature'dot; --Equivelant to a capacitor
  end procedural;
end architecture arch1;
